=================
QMI Documentation
=================

This is the documentation for QMI, the Quantum Measurement Infrastructure framework.

.. toctree::
   :caption: Table of Contents
   :maxdepth: 2

   welcome
   installation
   tutorial
   design
   api_reference
   coding_standard
   documenting_qmi

==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
